from a10sdk.common.A10BaseClass import A10BaseClass


class Buffered(A10BaseClass):
    
    """Class Description::
    Set buffered logging parameters.

    Class buffered supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param buffersize: {"description": "Logging buffer size (in items), default 30000", "partition-visibility": "shared", "default": 30000, "optional": true, "format": "number", "maximum": 50000, "minimum": 10000, "type": "number"}
    :param buffered_disable: {"description": "Do not send log to console", "format": "flag", "default": 0, "optional": true, "not": "levelname", "type": "number"}
    :param levelname: {"description": "'emergency': System unusable log messages      (severity=0); 'alert': Action must be taken immediately  (severity=1); 'critical': Critical conditions               (severity=2); 'error': Error conditions                  (severity=3); 'warning': Warning conditions                (severity=4); 'notification': Normal but significant conditions (severity=5); 'information': Informational messages            (severity=6); 'debugging': Debug level messages              (severity=7); ", "format": "enum", "default": "debugging", "optional": true, "enum": ["emergency", "alert", "critical", "error", "warning", "notification", "information", "debugging"], "not": "buffered-disable", "type": "string"}
    :param partition_buffersize: {"description": "Logging buffer size (in items), default 3000", "partition-visibility": "private", "default": 3000, "optional": true, "format": "number", "maximum": 5000, "minimum": 1000, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/logging/buffered`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "buffered"
        self.a10_url="/axapi/v3/logging/buffered"
        self.DeviceProxy = ""
        self.buffersize = ""
        self.buffered_disable = ""
        self.levelname = ""
        self.partition_buffersize = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Capacity(A10BaseClass):
    
    """Class Description::
    Select Service-IP for the device having highest available connection capacity.

    Class capacity supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param threshold: {"description": "Specify capacity threshold, default is 90", "format": "number", "default": 90, "optional": true, "maximum": 100, "minimum": 0, "type": "number"}
    :param capacity_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable capacity", "format": "flag"}
    :param capacity_fail_break: {"default": 0, "optional": true, "type": "number", "description": "Break when exceed threshold", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/policy/{name}/capacity`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "capacity"
        self.a10_url="/axapi/v3/gslb/policy/{name}/capacity"
        self.DeviceProxy = ""
        self.threshold = ""
        self.capacity_enable = ""
        self.capacity_fail_break = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Dns64(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param exclusive_answer: {"default": 0, "type": "number", "description": "Exclusive Answer in DNS Response", "format": "flag"}
    :param prefix: {"type": "string", "description": "IPv6 prefix", "format": "ipv6-address-plen"}
    :param disable: {"default": 0, "type": "number", "description": "Disable", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dns64"
        self.DeviceProxy = ""
        self.exclusive_answer = ""
        self.prefix = ""
        self.disable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Lid(A10BaseClass):
    
    """Class Description::
    Limit ID.

    Class lid supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param request_limit: {"description": "Request limit (Specify request limit)", "format": "number", "type": "number", "maximum": 1048575, "minimum": 0, "optional": true}
    :param conn_limit: {"description": "Connection limit", "format": "number", "type": "number", "maximum": 1048575, "minimum": 0, "optional": true}
    :param interval: {"description": "Specify log interval in minutes, by default system will log every over limit instance", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}
    :param log: {"default": 0, "optional": true, "type": "number", "description": "Log a message", "format": "flag"}
    :param lidnum: {"description": "Specify a limit ID", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": false}
    :param request_rate_limit: {"description": "Request rate limit (Specify request rate limit)", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 1, "optional": true}
    :param conn_per: {"description": "Per (Specify interval in number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param request_per: {"description": "Per (Specify interval in number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param conn_rate_limit: {"description": "Specify connection rate limit", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}
    :param lockout: {"description": "Don't accept any new connection for certain time (Lockout duration in minutes)", "format": "number", "type": "number", "maximum": 1023, "minimum": 1, "optional": true}
    :param action_value: {"optional": true, "enum": ["forward", "reset"], "type": "string", "description": "'forward': Forward the traffic even it exceeds limit; 'reset': Reset the connection when it exceeds limit; ", "format": "enum"}
    :param over_limit_action: {"default": 0, "optional": true, "type": "number", "description": "Set action when exceeds limit", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/template/policy/{name}/class-list/lid/{lidnum}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "lidnum"]

        self.b_key = "lid"
        self.a10_url="/axapi/v3/cgnv6/template/policy/{name}/class-list/lid/{lidnum}"
        self.DeviceProxy = ""
        self.request_limit = ""
        self.conn_limit = ""
        self.interval = ""
        self.log = ""
        self.dns64 = {}
        self.lidnum = ""
        self.request_rate_limit = ""
        self.conn_per = ""
        self.request_per = ""
        self.conn_rate_limit = ""
        self.lockout = ""
        self.action_value = ""
        self.over_limit_action = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AlternatePort(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param alternate_name: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Alternate Name", "format": "string-rlx"}
    :param alternate_server_port: {"description": "Port (Alternate Server Port Value)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param alternate: {"description": "Alternate Server Number", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "alternate-port"
        self.DeviceProxy = ""
        self.alternate_name = ""
        self.alternate_server_port = ""
        self.alternate = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AuthCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param service_principal_name: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Service Principal Name (Kerberos principal name)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "auth-cfg"
        self.DeviceProxy = ""
        self.service_principal_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Port(A10BaseClass):
    
    """Class Description::
    Real Server Port.

    Class port supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param conn_limit: {"description": "Connection Limit", "format": "number", "default": 8000000, "optional": true, "maximum": 8000000, "minimum": 1, "type": "number"}
    :param health_check_disable: {"description": "Disable health check", "format": "flag", "default": 0, "optional": true, "not-list": ["health-check", "health-check-follow-port"], "type": "number"}
    :param extended_stats: {"default": 0, "optional": true, "type": "number", "description": "Enable extended statistics on real server port", "format": "flag"}
    :param template_server_ssl: {"description": "Server side SSL template (Server side SSL Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/server-ssl"}
    :param weight: {"description": "Port Weight (Connection Weight)", "format": "number", "default": 1, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}
    :param conn_resume: {"description": "Connection Resume", "format": "number", "type": "number", "maximum": 1000000, "minimum": 1, "optional": true}
    :param alternate_port: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"alternate-name": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Alternate Name", "format": "string-rlx"}, "alternate-server-port": {"description": "Port (Alternate Server Port Value)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "alternate": {"description": "Alternate Server Number", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "optional": true}}]}
    :param no_logging: {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}
    :param stats_data_action: {"description": "'stats-data-enable': Enable statistical data collection for real server port; 'stats-data-disable': Disable statistical data collection for real server port; ", "format": "enum", "default": "stats-data-enable", "type": "string", "enum": ["stats-data-enable", "stats-data-disable"], "optional": true}
    :param follow_port_protocol: {"optional": true, "enum": ["tcp", "udp"], "type": "string", "description": "'tcp': TCP Port; 'udp': UDP Port; ", "format": "enum"}
    :param port_number: {"description": "Port Number", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": false}
    :param range: {"description": "Port range (Port range value - used for vip-to-rport-mapping)", "format": "number", "default": 0, "optional": true, "maximum": 254, "minimum": 0, "type": "number"}
    :param no_ssl: {"default": 0, "optional": true, "type": "number", "description": "No SSL", "format": "flag"}
    :param action: {"description": "'enable': enable; 'disable': disable; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}
    :param protocol: {"optional": false, "enum": ["tcp", "udp"], "type": "string", "description": "'tcp': TCP Port; 'udp': UDP Port; ", "format": "enum"}
    :param health_check_follow_port: {"description": "Specify which port to follow for health status (Port Number)", "format": "number", "optional": true, "not-list": ["health-check", "health-check-disable"], "maximum": 65534, "minimum": 1, "type": "number"}
    :param health_check: {"description": "Health Check (Monitor Name)", "format": "string", "minLength": 1, "not-list": ["health-check-follow-port", "health-check-disable"], "optional": true, "maxLength": 31, "type": "string", "$ref": "/axapi/v3/health/monitor"}
    :param template_port: {"description": "Port template (Port template name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/port"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/server/{name}/port/{port_number}+{protocol}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "port_number","protocol"]

        self.b_key = "port"
        self.a10_url="/axapi/v3/slb/server/{name}/port/{port_number}+{protocol}"
        self.DeviceProxy = ""
        self.conn_limit = ""
        self.health_check_disable = ""
        self.extended_stats = ""
        self.template_server_ssl = ""
        self.weight = ""
        self.conn_resume = ""
        self.alternate_port = []
        self.no_logging = ""
        self.stats_data_action = ""
        self.follow_port_protocol = ""
        self.port_number = ""
        self.A10WW_range = ""
        self.no_ssl = ""
        self.auth_cfg = {}
        self.action = ""
        self.protocol = ""
        self.health_check_follow_port = ""
        self.health_check = ""
        self.template_port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PreferredSessionSyncPort(A10BaseClass):
    
    """Class Description::
    VRRP-A preferred-session-sync-port.

    Class preferred-session-sync-port supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param trunk_list: {"minItems": 1, "items": {"type": "trunk"}, "uniqueItems": true, "array": [{"required": ["pre-trunk"], "properties": {"pre-vlan": {"description": "Interface VLAN (VLAN ID)", "format": "number", "type": "number", "maximum": 4094, "minimum": 1, "optional": true}, "pre-trunk": {"optional": false, "type": "number", "description": "Trunk Interface number", "format": "interface"}}}], "type": "array", "$ref": "/axapi/v3/vrrp-a/preferred-session-sync-port/trunk/{pre-trunk}"}
    :param ethernet_list: {"minItems": 1, "items": {"type": "ethernet"}, "uniqueItems": true, "array": [{"required": ["pre-eth"], "properties": {"pre-eth": {"optional": false, "type": "number", "description": "Ethernet interface number", "format": "interface"}, "pre-vlan": {"description": "Interface VLAN (VLAN ID)", "format": "number", "type": "number", "maximum": 4094, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/vrrp-a/preferred-session-sync-port/ethernet/{pre-eth}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a/preferred-session-sync-port`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "preferred-session-sync-port"
        self.a10_url="/axapi/v3/vrrp-a/preferred-session-sync-port"
        self.DeviceProxy = ""
        self.trunk_list = []
        self.ethernet_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Log(A10BaseClass):
    
    """Class Description::
    Router log options.

    Class log supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param log_buffer: {"default": 1, "optional": true, "type": "number", "description": "Logging goes to log-buffer", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/log`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "log"
        self.a10_url="/axapi/v3/router/log"
        self.DeviceProxy = ""
        self.log_buffer = ""
        self.A10WW_file = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Method(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param none: {"default": 0, "type": "number", "description": "No command authorization", "format": "flag"}
    :param tacplus: {"default": 0, "type": "number", "description": "Using TACACS+ protocol", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "method"
        self.DeviceProxy = ""
        self.none = ""
        self.tacplus = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Authorization(A10BaseClass):
    
    """Class Description::
    Configuration for command authorization.

    Class authorization supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param debug: {"description": "Specify the debug level for authorization (Debug level for command authorization. bitwise OR of the following: 1(common), 2(packet),4(packet detail), 8(md5))", "format": "number", "type": "number", "maximum": 15, "minimum": 1, "optional": true}
    :param commands: {"description": "Commands level for authorization", "format": "number", "type": "number", "maximum": 15, "minimum": 0, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/authorization`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "authorization"
        self.a10_url="/axapi/v3/authorization"
        self.DeviceProxy = ""
        self.debug = ""
        self.commands = ""
        self.method = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param data_session_freed: {"description": "Data Session Freed", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param port_overloading_smp_free_tcp: {"description": "TCP Port Overloading Session Freed", "format": "counter", "type": "number", "oid": "38", "optional": true, "size": "8"}
    :param total_udp_overloaded: {"description": "UDP Port Overloaded", "format": "counter", "type": "number", "oid": "35", "optional": true, "size": "8"}
    :param endpoint_indep_filter_match: {"description": "Endpoint-Independent Filtering Matched", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "8"}
    :param udp_fullcone_freed: {"description": "UDP Full-cone Session Freed", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param nat_pool_unusable: {"description": "NAT Pool Unusable", "format": "counter", "type": "number", "oid": "40", "optional": true, "size": "8"}
    :param nat_port_unavailable_udp: {"description": "UDP NAT Port Unavailable", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param lid_pass_through: {"description": "LSN LID Pass-through", "format": "counter", "type": "number", "oid": "47", "optional": true, "size": "8"}
    :param total_icmp_freed: {"description": "Total ICMP Ports Freed", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param hairpin: {"description": "Hairpin Session Created", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param tcp_fullcone_created: {"description": "TCP Full-cone Session Created", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param nat_port_unavailable_icmp: {"description": "ICMP NAT Port Unavailable", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param udp_fullcone_created: {"description": "UDP Full-cone Session Created", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param extended_quota_matched: {"description": "Extended User-Quota Matched", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param icmp_user_quota_exceeded: {"description": "ICMP User-Quota Exceeded", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param ha_nat_pool_unusable: {"description": "HA NAT Pool Unusable", "format": "counter", "type": "number", "oid": "41", "optional": true, "size": "8"}
    :param port_overloading_smp_free_udp: {"description": "UDP Port Overloading Session Freed", "format": "counter", "type": "number", "oid": "39", "optional": true, "size": "8"}
    :param total_tcp_allocated: {"description": "Total TCP Ports Allocated", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param tcp_user_quota_exceeded: {"description": "TCP User-Quota Exceeded", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param port_overloading_smp_inserted_tcp: {"description": "TCP Port Overloading Session Created", "format": "counter", "type": "number", "oid": "36", "optional": true, "size": "8"}
    :param eif_limit_exceeded: {"description": "Endpoint-Independent Filtering Inbound Limit Exceeded", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "8"}
    :param port_overloading_smp_inserted_udp: {"description": "UDP Port Overloading Session Created", "format": "counter", "type": "number", "oid": "37", "optional": true, "size": "8"}
    :param tcp_fullcone_freed: {"description": "TCP Full-cone Session Freed", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param user_quota_failure: {"description": "User-Quota Creation Failed", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param total_udp_freed: {"description": "Total UDP Ports Freed", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param nat_port_unavailable_tcp: {"description": "TCP NAT Port Unavailable", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param total_tcp_overloaded: {"description": "TCP Port Overloaded", "format": "counter", "type": "number", "oid": "34", "optional": true, "size": "8"}
    :param fullcone_failure: {"description": "Full-cone Session Creation Failed", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param user_quota_created: {"description": "User-Quota Created", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param data_sesn_user_quota_exceeded: {"description": "Data Session User-Quota Exceeded", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param nat_ip_max_udp_ports_allocated: {"description": "NAT IP UDP Max Ports Allocated", "format": "counter", "type": "number", "oid": "44", "optional": true, "size": "8"}
    :param nat_ip_max_tcp_ports_allocated: {"description": "NAT IP TCP Max Ports Allocated", "format": "counter", "type": "number", "oid": "43", "optional": true, "size": "8"}
    :param fullcone_self_hairpinning_drop: {"description": "Self-Hairpinning Drop", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "8"}
    :param nat_mismatch_drop: {"description": "NAT Pool Mismatch Drop", "format": "counter", "type": "number", "oid": "33", "optional": true, "size": "8"}
    :param new_user_resource_unavailable: {"description": "New User NAT Resource Unavailable", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param extended_quota_exceeded: {"description": "Extended User-Quota Exceeded", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param total_udp_allocated: {"description": "Total UDP Ports Allocated", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param data_session_created: {"description": "Data Session Created", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param user_quota_put_in_del_q: {"description": "User-Quota Freed", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param endpoint_indep_map_match: {"description": "Endpoint-Independent Mapping Matched", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "8"}
    :param udp_user_quota_exceeded: {"description": "UDP User-Quota Exceeded", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param no_radius_profile_match: {"description": "No RADIUS Profile Match", "format": "counter", "type": "number", "oid": "42", "optional": true, "size": "8"}
    :param total_icmp_allocated: {"description": "Total ICMP Ports Allocated", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param no_class_list_match: {"description": "No Class-List Match", "format": "counter", "type": "number", "oid": "45", "optional": true, "size": "8"}
    :param inbound_filtered: {"description": "Endpoint-Dependent Filtering Drop", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "8"}
    :param total_tcp_freed: {"description": "Total TCP Ports Freed", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param lid_drop: {"description": "LSN LID Drop", "format": "counter", "type": "number", "oid": "46", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.data_session_freed = ""
        self.port_overloading_smp_free_tcp = ""
        self.total_udp_overloaded = ""
        self.endpoint_indep_filter_match = ""
        self.udp_fullcone_freed = ""
        self.nat_pool_unusable = ""
        self.nat_port_unavailable_udp = ""
        self.lid_pass_through = ""
        self.total_icmp_freed = ""
        self.hairpin = ""
        self.tcp_fullcone_created = ""
        self.nat_port_unavailable_icmp = ""
        self.udp_fullcone_created = ""
        self.extended_quota_matched = ""
        self.icmp_user_quota_exceeded = ""
        self.ha_nat_pool_unusable = ""
        self.port_overloading_smp_free_udp = ""
        self.total_tcp_allocated = ""
        self.tcp_user_quota_exceeded = ""
        self.port_overloading_smp_inserted_tcp = ""
        self.eif_limit_exceeded = ""
        self.port_overloading_smp_inserted_udp = ""
        self.tcp_fullcone_freed = ""
        self.user_quota_failure = ""
        self.total_udp_freed = ""
        self.nat_port_unavailable_tcp = ""
        self.total_tcp_overloaded = ""
        self.fullcone_failure = ""
        self.user_quota_created = ""
        self.data_sesn_user_quota_exceeded = ""
        self.nat_ip_max_udp_ports_allocated = ""
        self.nat_ip_max_tcp_ports_allocated = ""
        self.fullcone_self_hairpinning_drop = ""
        self.nat_mismatch_drop = ""
        self.new_user_resource_unavailable = ""
        self.extended_quota_exceeded = ""
        self.total_udp_allocated = ""
        self.data_session_created = ""
        self.user_quota_put_in_del_q = ""
        self.endpoint_indep_map_match = ""
        self.udp_user_quota_exceeded = ""
        self.no_radius_profile_match = ""
        self.total_icmp_allocated = ""
        self.no_class_list_match = ""
        self.inbound_filtered = ""
        self.total_tcp_freed = ""
        self.lid_drop = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Global(A10BaseClass):
    
    """Class Description::
    Statistics for the object global.

    Class global supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lsn/global/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "global"
        self.a10_url="/axapi/v3/cgnv6/lsn/global/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PortReservation(A10BaseClass):
    
    """Class Description::
    DS-Lite Static Port Reservation.

    Class port-reservation supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param nat_end_port: {"description": "NAT End Port", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param inside: {"optional": false, "type": "string", "description": "Inside User Address and Port Range (DS-Lite Inside User's Tunnel Source IPv6 Address)", "format": "ipv6-address"}
    :param tunnel_dest_address: {"optional": false, "type": "string", "description": "DS-Lite Inside User's Tunnel Destination IPv6 Address", "format": "ipv6-address"}
    :param inside_start_port: {"description": "Inside Start Port", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param nat: {"optional": false, "type": "string", "description": "NAT Port Range (NAT IP address)", "format": "ipv4-address"}
    :param inside_end_port: {"description": "Inside End Port", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param nat_start_port: {"description": "NAT Start Port", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param inside_addr: {"optional": false, "type": "string", "description": "Inside User IP address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/ds-lite/port-reservation/{inside}+{tunnel_dest_address}+{inside_addr}+{inside_start_port}+{inside_end_port}+{nat}+{nat_start_port}+{nat_end_port}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "inside","tunnel_dest_address","inside_addr","inside_start_port","inside_end_port","nat","nat_start_port","nat_end_port"]

        self.b_key = "port-reservation"
        self.a10_url="/axapi/v3/cgnv6/ds-lite/port-reservation/{inside}+{tunnel_dest_address}+{inside_addr}+{inside_start_port}+{inside_end_port}+{nat}+{nat_start_port}+{nat_end_port}"
        self.DeviceProxy = ""
        self.nat_end_port = ""
        self.inside = ""
        self.tunnel_dest_address = ""
        self.inside_start_port = ""
        self.nat = ""
        self.inside_end_port = ""
        self.nat_start_port = ""
        self.inside_addr = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class FailMsgCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param fail_font_custom: {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "fail-face", "type": "string"}
    :param fail_color: {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}
    :param fail_size: {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}
    :param fail_msg: {"default": 0, "type": "number", "description": "Configure logon failure message in default logon fail page", "format": "flag"}
    :param fail_text: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify logon failure message (Default: Login Failed!!)", "format": "string-rlx"}
    :param fail_color_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "fail-color-name", "type": "string"}
    :param fail_font: {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}
    :param fail_color_name: {"not": "fail-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param fail_face: {"not": "fail-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "fail-msg-cfg"
        self.DeviceProxy = ""
        self.fail_font_custom = ""
        self.fail_color = ""
        self.fail_size = ""
        self.fail_msg = ""
        self.fail_text = ""
        self.fail_color_value = ""
        self.fail_font = ""
        self.fail_color_name = ""
        self.fail_face = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class WelcomeMsgCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param wel_color_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "wel-color-name", "type": "string"}
    :param wel_color_name: {"not": "wel-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param wel_font_custom: {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "wel-face", "type": "string"}
    :param wel_face: {"not": "wel-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}
    :param wel_font: {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}
    :param wel_size: {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}
    :param wel_color: {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}
    :param wel_text: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify welcome message (Deault: Try too many times.)", "format": "string-rlx"}
    :param welcome_msg: {"default": 0, "type": "number", "description": "Configure welcome message in default logon fail page", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "welcome-msg-cfg"
        self.DeviceProxy = ""
        self.wel_color_value = ""
        self.wel_color_name = ""
        self.wel_font_custom = ""
        self.wel_face = ""
        self.wel_font = ""
        self.wel_size = ""
        self.wel_color = ""
        self.wel_text = ""
        self.welcome_msg = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TitleCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param title: {"default": 0, "type": "number", "description": "Configure title in default logon fail page", "format": "flag"}
    :param title_color: {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}
    :param title_color_name: {"not": "title-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param title_font_custom: {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "title-face", "type": "string"}
    :param title_face: {"not": "title-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}
    :param title_color_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "title-color-name", "type": "string"}
    :param title_size: {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}
    :param title_text: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify title", "format": "string-rlx"}
    :param title_font: {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "title-cfg"
        self.DeviceProxy = ""
        self.title = ""
        self.title_color = ""
        self.title_color_name = ""
        self.title_font_custom = ""
        self.title_face = ""
        self.title_color_value = ""
        self.title_size = ""
        self.title_text = ""
        self.title_font = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Background(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param bgfile: {"description": "Specify background image filename", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "bgcolor", "type": "string"}
    :param bgstyle: {"enum": ["tile", "stretch", "fit"], "type": "string", "description": "'tile': Tile; 'stretch': Stretch; 'fit': Fit; ", "format": "enum"}
    :param bgcolor_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "bgcolor-name", "type": "string"}
    :param bgcolor_name: {"not": "bgcolor-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param bgcolor: {"default": 0, "not": "bgfile", "type": "number", "description": "Specify background color", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "background"
        self.DeviceProxy = ""
        self.bgfile = ""
        self.bgstyle = ""
        self.bgcolor_value = ""
        self.bgcolor_name = ""
        self.bgcolor = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NoteCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param note_text: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify notes", "format": "string-rlx"}
    :param note_color_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "note-color-name", "type": "string"}
    :param note_face: {"not": "note-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}
    :param note_font: {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}
    :param note_color: {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}
    :param note_size: {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}
    :param note: {"default": 0, "type": "number", "description": "Configure notes in default logon page", "format": "flag"}
    :param note_font_custom: {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "note-face", "type": "string"}
    :param note_color_name: {"not": "note-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "note-cfg"
        self.DeviceProxy = ""
        self.note_text = ""
        self.note_color_value = ""
        self.note_face = ""
        self.note_font = ""
        self.note_color = ""
        self.note_size = ""
        self.note = ""
        self.note_font_custom = ""
        self.note_color_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LogonFail(A10BaseClass):
    
    """Class Description::
    Logon fail page configuration.

    Class logon-fail supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/portal/{name}/logon-fail`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "logon-fail"
        self.a10_url="/axapi/v3/aam/authentication/portal/{name}/logon-fail"
        self.DeviceProxy = ""
        self.fail_msg_cfg = {}
        self.welcome_msg_cfg = {}
        self.title_cfg = {}
        self.background = {}
        self.note_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ModeCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param mode: {"default": 0, "type": "number", "description": "Configure authentication mode", "format": "flag"}
    :param mode_type: {"default": "\"single\"", "enum": ["multiple", "single"], "type": "string", "description": "'multiple': Multiple authentication mode. If an authentication method rejected, try next one; 'single': Single authentication mode. If an authentication method rejected, don't try next one; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "mode-cfg"
        self.DeviceProxy = ""
        self.mode = ""
        self.mode_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TypeCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param authen_type: {"enum": ["ldap", "local", "radius", "tacplus"], "type": "string", "format": "enum-list"}
    :param type: {"default": 0, "type": "number", "description": "The login authentication type", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "type-cfg"
        self.DeviceProxy = ""
        self.authen_type = ""
        self.A10WW_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LoginCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param local: {"default": 0, "type": "number", "description": "Configure local user to enter privilege-mode", "format": "flag"}
    :param privilege_mode: {"default": 0, "type": "number", "description": "Configure to enter privilege-mode", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "login-cfg"
        self.DeviceProxy = ""
        self.local = ""
        self.privilege_mode = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class EnableCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param enable_auth_type: {"enum": ["local", "tacplus"], "type": "string", "format": "enum-list"}
    :param enable: {"default": 0, "type": "number", "description": "The enable-password authentication type", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "enable-cfg"
        self.DeviceProxy = ""
        self.enable_auth_type = ""
        self.enable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Authentication(A10BaseClass):
    
    """Class Description::
    Configure authentication feature.

    Class authentication supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param multiple_auth_reject: {"default": 0, "optional": true, "type": "number", "description": "Multiple same user login reject", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/authentication`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "authentication"
        self.a10_url="/axapi/v3/authentication"
        self.DeviceProxy = ""
        self.console = {}
        self.mode_cfg = {}
        self.type_cfg = {}
        self.multiple_auth_reject = ""
        self.login_cfg = {}
        self.enable_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Vnp(A10BaseClass):
    
    """Class Description::
    module VNP.

    Class VNP supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param logging: {"optional": true, "enum": ["on", "off"], "type": "string", "description": "'on': enable this action; 'off': disable this action; ", "format": "enum"}
    :param VNP_evnts: {"optional": false, "enum": ["part-create", "part-del"], "type": "string", "description": "'part-create': Create new partition; 'part-del': Delete a partition; ", "format": "enum"}
    :param email: {"optional": true, "enum": ["on", "off"], "type": "string", "description": "'on': enable this action; 'off': disable this action; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/event/VNP/{VNP_evnts}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "VNP_evnts"]

        self.b_key = "VNP"
        self.a10_url="/axapi/v3/event/VNP/{VNP_evnts}"
        self.DeviceProxy = ""
        self.logging = ""
        self.VNP_evnts = ""
        self.email = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class DsLite(A10BaseClass):
    
    """Class Description::
    Configure Dual-Stack Lite (DS-Lite).

    Class ds-lite supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param port_reservation_list: {"minItems": 1, "items": {"type": "port-reservation"}, "uniqueItems": true, "array": [{"required": ["inside", "tunnel-dest-address", "inside-addr", "inside-start-port", "inside-end-port", "nat", "nat-start-port", "nat-end-port"], "properties": {"nat-end-port": {"description": "NAT End Port", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}, "inside": {"optional": false, "type": "string", "description": "Inside User Address and Port Range (DS-Lite Inside User's Tunnel Source IPv6 Address)", "format": "ipv6-address"}, "tunnel-dest-address": {"optional": false, "type": "string", "description": "DS-Lite Inside User's Tunnel Destination IPv6 Address", "format": "ipv6-address"}, "inside-start-port": {"description": "Inside Start Port", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}, "nat": {"optional": false, "type": "string", "description": "NAT Port Range (NAT IP address)", "format": "ipv4-address"}, "inside-end-port": {"description": "Inside End Port", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}, "nat-start-port": {"description": "NAT Start Port", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}, "inside-addr": {"optional": false, "type": "string", "description": "Inside User IP address", "format": "ipv4-address"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/ds-lite/port-reservation/{inside}+{tunnel-dest-address}+{inside-addr}+{inside-start-port}+{inside-end-port}+{nat}+{nat-start-port}+{nat-end-port}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/ds-lite`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ds-lite"
        self.a10_url="/axapi/v3/cgnv6/ds-lite"
        self.DeviceProxy = ""
        self.alg = {}
        self.fragmentation = {}
        self.A10WW_global = {}
        self.port_reservation_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PortList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param management: {"type": "number", "format": "number"}
    :param ve: {"type": "number", "format": "number"}
    :param ipv6_acl: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param ipv4_acl: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param action: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param ethernet: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "port-list"
        self.DeviceProxy = ""
        self.management = ""
        self.ve = ""
        self.ipv6_acl = ""
        self.ipv4_acl = ""
        self.action = ""
        self.ethernet = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param port_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"management": {"type": "number", "format": "number"}, "ve": {"type": "number", "format": "number"}, "ipv6-acl": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "ipv4-acl": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "action": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "ethernet": {"type": "number", "format": "number"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.port_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Http(A10BaseClass):
    
    """Class Description::
    Operational Status for the object http.

    Class http supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/enable-management/http/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "http"
        self.a10_url="/axapi/v3/enable-management/http/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Password(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param encrypted: {"type": "encrypted", "description": " Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param smtp_password: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Configure SMTP login password", "format": "password"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "password"
        self.DeviceProxy = ""
        self.encrypted = ""
        self.smtp_password = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class UsernameCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param username: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Configure SMTP login username", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "username-cfg"
        self.DeviceProxy = ""
        self.username = ""
        self.password = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Smtp(A10BaseClass):
    
    """Class Description::
    Configure SMTP Server.

    Class smtp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param mailfrom: {"description": "Configure email source address", "format": "email-addr", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param smtp_server: {"description": "Configure SMTP Server (length:1-31)", "format": "host", "minLength": 1, "optional": true, "maxLength": 31, "not": "smtp-server-v6", "type": "string"}
    :param needauthentication: {"default": 0, "optional": true, "type": "number", "description": "Configure SMTP server need authtication", "format": "flag"}
    :param port: {"description": "Configure SMTP Port (Configure SMTP port, default is 25)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param smtp_server_v6: {"not": "smtp-server", "optional": true, "type": "string", "description": "Configure SMTP Server IPV6 address", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/smtp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "smtp"
        self.a10_url="/axapi/v3/smtp"
        self.DeviceProxy = ""
        self.mailfrom = ""
        self.smtp_server = ""
        self.username_cfg = {}
        self.needauthentication = ""
        self.port = ""
        self.smtp_server_v6 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class HelperAddressList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param helper_address: {"type": "string", "description": "Helper address for DHCP packets (IP address)", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "helper-address-list"
        self.DeviceProxy = ""
        self.helper_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AddressList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv4_address: {"type": "string", "description": "IP address", "format": "ipv4-address"}
    :param ipv4_netmask: {"type": "string", "description": "IP subnet mask", "format": "ipv4-netmask"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "address-list"
        self.DeviceProxy = ""
        self.ipv4_address = ""
        self.ipv4_netmask = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ip(A10BaseClass):
    
    """Class Description::
    Global IP configuration subcommands.

    Class ip supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param generate_membership_query: {"default": 0, "optional": true, "type": "number", "description": "Enable Membership Query", "format": "flag"}
    :param cache_spoofing_port: {"default": 0, "optional": true, "type": "number", "description": "This interface connects to spoofing cache", "format": "flag"}
    :param inside: {"default": 0, "optional": true, "type": "number", "description": "Configure interface as inside", "format": "flag"}
    :param allow_promiscuous_vip: {"default": 0, "optional": true, "type": "number", "description": "Allow traffic to be associated with promiscuous VIP", "format": "flag"}
    :param max_resp_time: {"description": "Maximum Response Time (Max Response Time (Default is 100))", "format": "number", "default": 100, "optional": true, "maximum": 255, "minimum": 1, "type": "number"}
    :param query_interval: {"description": "1 - 255 (Default is 125)", "format": "number", "default": 125, "optional": true, "maximum": 255, "minimum": 1, "type": "number"}
    :param outside: {"default": 0, "optional": true, "type": "number", "description": "Configure interface as outside", "format": "flag"}
    :param helper_address_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"helper-address": {"type": "string", "description": "Helper address for DHCP packets (IP address)", "format": "ipv4-address"}, "optional": true}}]}
    :param address_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv4-address": {"type": "string", "description": "IP address", "format": "ipv4-address"}, "optional": true, "ipv4-netmask": {"type": "string", "description": "IP subnet mask", "format": "ipv4-netmask"}}}]}
    :param dhcp: {"default": 0, "optional": true, "type": "number", "description": "Use DHCP to configure IP address", "format": "flag"}
    :param slb_partition_redirect: {"default": 0, "optional": true, "type": "number", "description": "Redirect SLB traffic across partition", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/ethernet/{ifnum}/ip`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ip"
        self.a10_url="/axapi/v3/interface/ethernet/{ifnum}/ip"
        self.DeviceProxy = ""
        self.generate_membership_query = ""
        self.cache_spoofing_port = ""
        self.inside = ""
        self.router = {}
        self.allow_promiscuous_vip = ""
        self.max_resp_time = ""
        self.query_interval = ""
        self.outside = ""
        self.helper_address_list = []
        self.stateful_firewall = {}
        self.rip = {}
        self.address_list = []
        self.dhcp = ""
        self.ospf = {}
        self.slb_partition_redirect = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ResetOnError(A10BaseClass):
    
    """Class Description::
    Send TCP resets for invalid sessions (Default: enabled).

    Class reset-on-error supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param outbound: {"optional": true, "enum": ["disable"], "type": "string", "description": "'disable': Disable send TCP reset on error; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lsn/tcp/reset-on-error`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "reset-on-error"
        self.a10_url="/axapi/v3/cgnv6/lsn/tcp/reset-on-error"
        self.DeviceProxy = ""
        self.outbound = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Policy(A10BaseClass):
    
    """Class Description::
    Policy for GSLB zone, service or geo-location.

    Class policy supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param weighted_ip_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable Select Service-IP by weighted preference", "format": "flag"}
    :param alias_admin_preference: {"default": 0, "optional": true, "type": "number", "description": "Select alias name having maximum admin preference", "format": "flag"}
    :param least_response: {"default": 0, "optional": true, "type": "number", "description": "Least response selection", "format": "flag"}
    :param bw_cost_fail_break: {"default": 0, "optional": true, "type": "number", "description": "Break when exceed limit", "format": "flag"}
    :param metric_fail_break: {"default": 0, "optional": true, "type": "number", "description": "Break if no valid Service-IP", "format": "flag"}
    :param weighted_ip: {"default": 0, "optional": true, "type": "number", "description": "Select Service-IP by weighted preference", "format": "flag"}
    :param round_robin: {"default": 1, "optional": true, "type": "number", "description": "Round robin selection, enabled by default", "format": "flag"}
    :param metric_type: {"optional": true, "enum": ["health-check", "weighted-ip", "weighted-site", "capacity", "active-servers", "active-rdt", "geographic", "connection-load", "num-session", "admin-preference", "bw-cost", "least-response", "admin-ip"], "type": "string", "format": "enum-list"}
    :param num_session_tolerance: {"description": "The difference between the available sessions, default is 10 (Tolerance)", "format": "number", "default": 10, "optional": true, "maximum": 100, "minimum": 0, "type": "number"}
    :param metric_order: {"default": 0, "optional": true, "type": "number", "description": "Specify order of metric", "format": "flag"}
    :param top_only: {"default": 0, "optional": true, "type": "number", "description": "Return highest priority server only", "format": "flag"}
    :param weighted_ip_total_hits: {"default": 0, "optional": true, "type": "number", "description": "Weighted by total hits", "format": "flag"}
    :param weighted_site_total_hits: {"default": 0, "optional": true, "type": "number", "description": "Weighted by total hits", "format": "flag"}
    :param weighted_site_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable Select Service-IP by weighted site preference", "format": "flag"}
    :param bw_cost: {"default": 0, "optional": true, "type": "number", "description": "Select site with minimum bandwidth cost", "format": "flag"}
    :param metric_force_check: {"default": 0, "optional": true, "type": "number", "description": "Always check Service-IP for all enabled metrics", "format": "flag"}
    :param admin_ip_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable admin ip", "format": "flag"}
    :param geo_location_list: {"minItems": 1, "items": {"type": "geo-location"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"ip-multiple-fields": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ip-addr2-sub": {"type": "string", "description": "Specify IP address range", "format": "ipv4-address"}, "optional": true, "ip-sub": {"type": "string", "description": "Specify IP information", "format": "ipv4-address"}, "ip-mask-sub": {"type": "string", "description": "Specify IP/mask format (Specify IP address mask)", "format": "ipv4-netmask-brief"}}}]}, "name": {"description": "Specify geo-location name, section range is (1-15)", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "ipv6-multiple-fields": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv6-mask-sub": {"description": "Specify IPv6/mask format (Specify IP address mask)", "minimum": 0, "type": "number", "maximum": 128, "format": "number"}, "ipv6-sub": {"type": "string", "description": "Specify IPv6 information", "format": "ipv6-address"}, "optional": true, "ipv6-addr2-sub": {"type": "string", "description": "Specify IPv6 address range", "format": "ipv6-address"}}}]}}}], "type": "array", "$ref": "/axapi/v3/gslb/policy/{name}/geo-location/{name}"}
    :param weighted_alias: {"default": 0, "optional": true, "type": "number", "description": "Select alias name by weighted preference", "format": "flag"}
    :param bw_cost_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable bw cost", "format": "flag"}
    :param num_session_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable Select Service-IP for device having maximum number of available sessions", "format": "flag"}
    :param name: {"description": "Specify policy name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param active_servers_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable Select Service-IP with the highest number of active servers", "format": "flag"}
    :param admin_ip: {"default": 0, "optional": true, "type": "number", "description": "Select Service-IP based on admin list", "format": "flag"}
    :param active_servers_fail_break: {"default": 0, "optional": true, "type": "number", "description": "Break when no active server", "format": "flag"}
    :param ip_list: {"description": "Specify IP List (IP List Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/gslb/ip-list"}
    :param admin_preference: {"default": 0, "optional": true, "type": "number", "description": "Select Service-IP for the device having maximum admin preference", "format": "flag"}
    :param weighted_site: {"default": 0, "optional": true, "type": "number", "description": "Select Service-IP by weighted site preference", "format": "flag"}
    :param geographic: {"default": 1, "optional": true, "type": "number", "description": "Select Service-IP by geographic", "format": "flag"}
    :param health_check: {"default": 1, "optional": true, "type": "number", "description": "Select Service-IP by health status", "format": "flag"}
    :param active_servers: {"default": 0, "optional": true, "type": "number", "description": "Select Service-IP with the highest number of active servers", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/policy/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "policy"
        self.a10_url="/axapi/v3/gslb/policy/{name}"
        self.DeviceProxy = ""
        self.weighted_ip_enable = ""
        self.alias_admin_preference = ""
        self.least_response = ""
        self.auto_map = {}
        self.bw_cost_fail_break = ""
        self.metric_fail_break = ""
        self.weighted_ip = ""
        self.active_rdt = {}
        self.round_robin = ""
        self.capacity = {}
        self.metric_type = ""
        self.num_session_tolerance = ""
        self.geo_location_match = {}
        self.metric_order = ""
        self.top_only = ""
        self.dns = {}
        self.weighted_ip_total_hits = ""
        self.weighted_site_total_hits = ""
        self.weighted_site_enable = ""
        self.bw_cost = ""
        self.metric_force_check = ""
        self.admin_ip_enable = ""
        self.geo_location_list = []
        self.weighted_alias = ""
        self.bw_cost_enable = ""
        self.num_session_enable = ""
        self.name = ""
        self.active_servers_enable = ""
        self.admin_ip = ""
        self.active_servers_fail_break = ""
        self.connection_load = {}
        self.ip_list = ""
        self.admin_preference = ""
        self.weighted_site = ""
        self.geographic = ""
        self.health_check = ""
        self.active_servers = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Host(A10BaseClass):
    
    """Class Description::
    Specify hosts to receive SNMP traps.

    Class host supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ipv6_host_list: {"minItems": 1, "items": {"type": "ipv6-host"}, "uniqueItems": true, "array": [{"required": ["ipv6-addr", "version"], "properties": {"udp-port": {"description": "The trap host's UDP port number(default: 162)", "format": "number", "default": 162, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "version": {"description": "'v1': Use SNMPv1; 'v2c': Use SNMPv2c; 'v3': User SNMPv3; ", "format": "enum", "default": "v2c", "type": "string", "enum": ["v1", "v2c", "v3"], "optional": false}, "ipv6-addr": {"optional": false, "type": "string", "description": "help IPV4 address of SNMP trap host", "format": "ipv6-address"}, "user": {"description": "SNMPv3 user to send traps (User Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "v1-v2c-comm": {"description": "SNMPv1/v2c community string", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/snmp-server/host/ipv6-host/{ipv6-addr}+{version}"}
    :param host_name_list: {"minItems": 1, "items": {"type": "host-name"}, "uniqueItems": true, "array": [{"required": ["hostname", "version"], "properties": {"udp-port": {"description": "The trap host's UDP port number(default: 162)", "format": "number", "default": 162, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "hostname": {"description": "Hostname of SNMP trap host", "format": "string", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}, "v1-v2c-comm": {"description": "SNMPv1/v2c community string", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "version": {"description": "'v1': Use SNMPv1; 'v2c': Use SNMPv2c; 'v3': User SNMPv3; ", "format": "enum", "default": "v2c", "type": "string", "enum": ["v1", "v2c", "v3"], "optional": false}, "user": {"description": "SNMPv3 user to send traps (User Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/snmp-server/host/host-name/{hostname}+{version}"}
    :param ipv4_host_list: {"minItems": 1, "items": {"type": "ipv4-host"}, "uniqueItems": true, "array": [{"required": ["ipv4-addr", "version"], "properties": {"ipv4-addr": {"optional": false, "type": "string", "description": "help IPV4 address of SNMP trap host", "format": "ipv4-address"}, "version": {"description": "'v1': Use SNMPv1; 'v2c': Use SNMPv2c; 'v3': User SNMPv3; ", "format": "enum", "default": "v2c", "type": "string", "enum": ["v1", "v2c", "v3"], "optional": false}, "v1-v2c-comm": {"description": "SNMPv1/v2c community string", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "user": {"description": "SNMPv3 user to send traps (User Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "udp-port": {"description": "The trap host's UDP port number(default: 162)", "format": "number", "default": 162, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/snmp-server/host/ipv4-host/{ipv4-addr}+{version}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/host`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "host"
        self.a10_url="/axapi/v3/snmp-server/host"
        self.DeviceProxy = ""
        self.ipv6_host_list = []
        self.host_name_list = []
        self.ipv4_host_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Service(A10BaseClass):
    
    """Class Description::
    Enable management services.

    Class service supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param acl_v6_list: {"minItems": 1, "items": {"type": "acl-v6"}, "uniqueItems": true, "array": [{"required": ["acl-name"], "properties": {"acl-name": {"description": "ACL name", "format": "string", "minLength": 1, "optional": false, "maxLength": 16, "type": "string"}, "ve-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ve-end": {"type": "number", "description": "VE port", "format": "number"}, "ve-start": {"type": "number", "description": "VE port (VE Interface number)", "format": "number"}, "optional": true}}]}, "eth-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet-start": {"type": "number", "description": "Ethernet port (Ethernet Interface number)", "format": "interface"}, "ethernet-end": {"type": "number", "description": "Ethernet port", "format": "interface"}, "optional": true}}]}}}], "type": "array", "$ref": "/axapi/v3/enable-management/service/acl-v6/{acl-name}"}
    :param acl_v4_list: {"minItems": 1, "items": {"type": "acl-v4"}, "uniqueItems": true, "array": [{"required": ["acl-id"], "properties": {"ve-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ve-end": {"type": "number", "description": "VE port", "format": "number"}, "ve-start": {"type": "number", "description": "VE port (VE Interface number)", "format": "number"}, "optional": true}}]}, "acl-id": {"description": "ACL id", "format": "number", "type": "number", "maximum": 199, "minimum": 1, "optional": false}, "eth-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet-start": {"type": "number", "description": "Ethernet port (Ethernet Interface number)", "format": "interface"}, "ethernet-end": {"type": "number", "description": "Ethernet port", "format": "interface"}, "optional": true}}]}}}], "type": "array", "$ref": "/axapi/v3/enable-management/service/acl-v4/{acl-id}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/enable-management/service`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "service"
        self.a10_url="/axapi/v3/enable-management/service"
        self.DeviceProxy = ""
        self.http = {}
        self.ping = {}
        self.snmp = {}
        self.telnet = {}
        self.acl_v6_list = []
        self.ssh = {}
        self.https = {}
        self.acl_v4_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param query_passive: {"description": "Query Passive", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param resp_local: {"description": "Response Local", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param adjust: {"description": "Translated", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param query_bad_pkt: {"description": "Query Bad Packet", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param resp: {"description": "Response", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param cache: {"description": "Cache", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param resp_empty: {"description": "Response Empty", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param resp_chg: {"description": "Response Changed", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param query_parallel: {"description": "Query Parallel", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param resp_bad_qr: {"description": "Response Bad Query", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param query: {"description": "Query", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param drop: {"description": "Dropped", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param resp_err: {"description": "Response Error", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param resp_bad_pkt: {"description": "Response Bad Packet", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param query_chg: {"description": "Query Changed", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.query_passive = ""
        self.resp_local = ""
        self.adjust = ""
        self.query_bad_pkt = ""
        self.resp = ""
        self.cache = ""
        self.resp_empty = ""
        self.resp_chg = ""
        self.query_parallel = ""
        self.resp_bad_qr = ""
        self.query = ""
        self.drop = ""
        self.resp_err = ""
        self.resp_bad_pkt = ""
        self.query_chg = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Dns64(A10BaseClass):
    
    """Class Description::
    Statistics for the object dns64.

    Class dns64 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/dns64/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "dns64"
        self.a10_url="/axapi/v3/cgnv6/dns64/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Access(A10BaseClass):
    
    """Class Description::
    Config access type.

    Class access supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param access_type: {"default": "axapi,cli,web", "optional": true, "enum": ["axapi", "cli", "web"], "type": "string", "format": "enum-list"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/admin/{user}/access`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "access"
        self.a10_url="/axapi/v3/admin/{user}/access"
        self.DeviceProxy = ""
        self.access_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PrimaryList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param primary: {"type": "string", "description": "Specify Primary controller's IP address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "primary-list"
        self.DeviceProxy = ""
        self.primary = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Group(A10BaseClass):
    
    """Class Description::
    GSLB Group.

    Class group supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param enable: {"default": 0, "optional": true, "type": "number", "description": "Join GSLB Group", "format": "flag"}
    :param name: {"description": "Specify Group domain name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param standalone: {"default": 0, "optional": true, "type": "number", "description": "Run GSLB Group in standalone mode", "format": "flag"}
    :param learn: {"default": 1, "optional": true, "type": "number", "description": "Learn neighbour information from other controllers", "format": "flag"}
    :param mgmt_interface: {"default": 1, "optional": true, "type": "number", "description": "Management Interface IP Address", "format": "flag"}
    :param dns_discover: {"default": 1, "optional": true, "type": "number", "description": "Discover member via DNS Protocol", "format": "flag"}
    :param priority: {"description": "Specify Local Priority, default is 100", "format": "number", "default": 100, "optional": true, "maximum": 255, "minimum": 1, "type": "number"}
    :param config_anywhere: {"default": 0, "optional": true, "type": "number", "description": "Every member can do config", "format": "flag"}
    :param data_interface: {"default": 1, "optional": true, "type": "number", "description": "Data Interface IP Address", "format": "flag"}
    :param auto_map_primary: {"default": 1, "optional": true, "type": "number", "description": "Primary Controller's IP address", "format": "flag"}
    :param auto_map_learn: {"default": 1, "optional": true, "type": "number", "description": "IP Address learned from other controller", "format": "flag"}
    :param primary_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "primary": {"type": "string", "description": "Specify Primary controller's IP address", "format": "ipv4-address"}}}]}
    :param suffix: {"description": "Set DNS Suffix (Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param config_merge: {"default": 0, "optional": true, "type": "number", "description": "Merge old master's config when new one take over", "format": "flag"}
    :param auto_map_smart: {"default": 1, "optional": true, "type": "number", "description": "Choose Best IP address", "format": "flag"}
    :param config_save: {"default": 1, "optional": true, "type": "number", "description": "Accept config-save message from master", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/group/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "group"
        self.a10_url="/axapi/v3/gslb/group/{name}"
        self.DeviceProxy = ""
        self.enable = ""
        self.name = ""
        self.standalone = ""
        self.learn = ""
        self.mgmt_interface = ""
        self.dns_discover = ""
        self.priority = ""
        self.config_anywhere = ""
        self.data_interface = ""
        self.auto_map_primary = ""
        self.auto_map_learn = ""
        self.primary_list = []
        self.suffix = ""
        self.config_merge = ""
        self.auto_map_smart = ""
        self.config_save = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class TxDot1Cfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param link_aggregation: {"default": 0, "type": "number", "description": "Interface link aggregation information", "format": "flag"}
    :param vlan: {"default": 0, "type": "number", "description": "Interface vlan information", "format": "flag"}
    :param tx_dot1_tlvs: {"default": 0, "type": "number", "description": "Interface lldp tx IEEE 802.1 Organizationally specific TLVs configuration", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "tx-dot1-cfg"
        self.DeviceProxy = ""
        self.link_aggregation = ""
        self.vlan = ""
        self.tx_dot1_tlvs = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NotificationCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param notification: {"default": 0, "type": "number", "description": "Interface lldp notification configuration", "format": "flag"}
    :param notif_enable: {"default": 0, "type": "number", "description": "Interface lldp notification enable", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "notification-cfg"
        self.DeviceProxy = ""
        self.notification = ""
        self.notif_enable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TxTlvsCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param system_capabilities: {"default": 0, "type": "number", "description": "Interface lldp system capabilities", "format": "flag"}
    :param system_description: {"default": 0, "type": "number", "description": "Interface lldp system description", "format": "flag"}
    :param management_address: {"default": 0, "type": "number", "description": "Interface lldp management address", "format": "flag"}
    :param tx_tlvs: {"default": 0, "type": "number", "description": "Interface lldp tx TLVs configuration", "format": "flag"}
    :param exclude: {"default": 0, "type": "number", "description": "Configure which TLVs excluded. All basic TLVs will be included by default", "format": "flag"}
    :param port_description: {"default": 0, "type": "number", "description": "Interface lldp port description", "format": "flag"}
    :param system_name: {"default": 0, "type": "number", "description": "Interface lldp system name", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "tx-tlvs-cfg"
        self.DeviceProxy = ""
        self.system_capabilities = ""
        self.system_description = ""
        self.management_address = ""
        self.tx_tlvs = ""
        self.exclude = ""
        self.port_description = ""
        self.system_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class EnableCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param rx: {"default": 0, "type": "number", "description": "Enable lldp rx", "format": "flag"}
    :param tx: {"default": 0, "type": "number", "description": "Enable lldp tx", "format": "flag"}
    :param rt_enable: {"default": 0, "type": "number", "description": "Interface lldp enable/disable", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "enable-cfg"
        self.DeviceProxy = ""
        self.rx = ""
        self.tx = ""
        self.rt_enable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Lldp(A10BaseClass):
    
    """Class Description::
    Interface lldp configuration.

    Class lldp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/management/lldp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "lldp"
        self.a10_url="/axapi/v3/interface/management/lldp"
        self.DeviceProxy = ""
        self.tx_dot1_cfg = {}
        self.notification_cfg = {}
        self.tx_tlvs_cfg = {}
        self.enable_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class DnssecTemplateKsk(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ksk_keysize_k: {"default": 0, "type": "number", "description": "Specify the number of bits in the DNSSEC KSK keys", "format": "flag"}
    :param zsk_rollover_time_v: {"description": "7 days less than the lifetime by default", "format": "number", "default": 358, "maximum": 3650, "minimum": 1, "type": "number"}
    :param ksk_lifetime_v: {"description": "Default value is 365 days", "minimum": 2, "type": "number", "maximum": 3650, "format": "number"}
    :param ksk_keysize_v: {"description": "Default size is 2048 and must be an exact multiple of 64", "minimum": 1024, "type": "number", "maximum": 4096, "format": "number"}
    :param ksk_rollover_time_k: {"default": 0, "type": "number", "description": "Set the rollover time in days", "format": "flag"}
    :param ksk_lifetime_k: {"default": 0, "type": "number", "description": "Set the lifetime for DNSSEC KSK keys in days", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dnssec-template-ksk"
        self.DeviceProxy = ""
        self.ksk_keysize_k = ""
        self.zsk_rollover_time_v = ""
        self.ksk_lifetime_v = ""
        self.ksk_keysize_v = ""
        self.ksk_rollover_time_k = ""
        self.ksk_lifetime_k = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DnssecTemplateZsk(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param zsk_keysize_v: {"description": "Default size is 2048 and must be an exact multiple of 64", "minimum": 1024, "type": "number", "maximum": 4096, "format": "number"}
    :param zsk_rollover_time_v: {"description": "7 days less than the lifetime by default", "format": "number", "default": 83, "maximum": 3650, "minimum": 1, "type": "number"}
    :param zsk_lifetime_v: {"description": "Default value is 90 days", "format": "number", "default": 90, "maximum": 3650, "minimum": 2, "type": "number"}
    :param zsk_lifetime_k: {"default": 0, "type": "number", "description": "Set the lifetime for DNSSEC ZSK keys in days", "format": "flag"}
    :param zsk_keysize_k: {"default": 0, "type": "number", "description": "Specify the number of bits in the DNSSEC ZSK keys", "format": "flag"}
    :param zsk_rollover_time_k: {"default": 0, "type": "number", "description": "Set the rollover time in days", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dnssec-template-zsk"
        self.DeviceProxy = ""
        self.zsk_keysize_v = ""
        self.zsk_rollover_time_v = ""
        self.zsk_lifetime_v = ""
        self.zsk_lifetime_k = ""
        self.zsk_keysize_k = ""
        self.zsk_rollover_time_k = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Template(A10BaseClass):
    
    """Class Description::
    template Settings.

    Class template supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param algorithm: {"optional": true, "enum": ["RSASHA1", "RSASHA256", "RSASHA512"], "type": "string", "description": "'RSASHA1': RSASHA1 algorithm; 'RSASHA256': RSASHA256 algorithm; 'RSASHA512': RSASHA512 algorithm; ", "format": "enum"}
    :param combinations_limit: {"description": "the max number of combinations per RRset (Default value is 31)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param dnskey_ttl_k: {"default": 0, "optional": true, "type": "number", "description": "The TTL value of DNSKEY RR", "format": "flag"}
    :param signature_validity_period_k: {"default": 0, "optional": true, "type": "number", "description": "The period that a signature is valid", "format": "flag"}
    :param hsm: {"description": "specify the HSM template", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/hsm/template"}
    :param enable_nsec3: {"default": 0, "optional": true, "type": "number", "description": "enable NSEC3 support. disabled by default", "format": "flag"}
    :param return_nsec_on_failure: {"default": 1, "optional": true, "type": "number", "description": "return NSEC/NSEC3 or not on failure case. return by default", "format": "flag"}
    :param dnskey_ttl_v: {"description": "in seconds, 14400 seconds by default", "format": "number", "default": 14400, "optional": true, "maximum": 864000, "minimum": 1, "type": "number"}
    :param dnssec_temp_name: {"description": "DNSSEC Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param signature_validity_period_v: {"description": "in days, 10 days by default", "format": "number", "default": 10, "optional": true, "maximum": 30, "minimum": 5, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/dnssec/template/{dnssec_temp_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "dnssec_temp_name"]

        self.b_key = "template"
        self.a10_url="/axapi/v3/dnssec/template/{dnssec_temp_name}"
        self.DeviceProxy = ""
        self.dnssec_template_ksk = {}
        self.algorithm = ""
        self.combinations_limit = ""
        self.dnskey_ttl_k = ""
        self.signature_validity_period_k = ""
        self.hsm = ""
        self.enable_nsec3 = ""
        self.return_nsec_on_failure = ""
        self.dnskey_ttl_v = ""
        self.dnssec_temp_name = ""
        self.signature_validity_period_v = ""
        self.dnssec_template_zsk = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Server(A10BaseClass):
    
    """Class Description::
    Set NTP time server.

    Class server supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param hostname_list: {"minItems": 1, "items": {"type": "hostname"}, "uniqueItems": true, "array": [{"required": ["host-servername"], "properties": {"action": {"description": "'enable': Enable this NTP server; 'disable': Disable this NTP server; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "prefer": {"default": 0, "optional": true, "type": "number", "description": "Set this NTP server as preferred", "format": "flag"}, "host-servername": {"description": "IPV4 address, IPV6 address or host name of NTP server(string1~63)", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "key": {"description": "Use trusted key to authenticate this NTP server (The trusted key number to use)", "format": "number", "optional": true, "maximum": 65535, "minimum": 1, "type": "number", "$ref": "/axapi/v3/ntp/trusted-key"}}}], "type": "array", "$ref": "/axapi/v3/ntp/server/hostname/{host-servername}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ntp/server`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "server"
        self.a10_url="/axapi/v3/ntp/server"
        self.DeviceProxy = ""
        self.hostname_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class InterfaceIpv6(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv6_ve: {"description": "configure lldp management-address interface ve (lldp management-address interface port number)", "minimum": 2, "type": "number", "maximum": 4094, "format": "number"}
    :param ipv6_eth: {"type": "number", "description": "configure lldp management-address interface ethernet (lldp management-address interface port number)", "format": "interface"}
    :param ipv6_mgmt: {"default": 0, "type": "number", "description": "configure lldp management-address interface management", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "interface-ipv6"
        self.DeviceProxy = ""
        self.ipv6_ve = ""
        self.ipv6_eth = ""
        self.ipv6_mgmt = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6Addr(A10BaseClass):
    
    """Class Description::
    Configure lldp management-address ipv6 address.

    Class ipv6-addr supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ipv6: {"optional": false, "type": "string", "description": "Configure lldp management-address, subtype is ipv6 (lldp management-address ipv6 address)", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/network/lldp/management-address/ipv6-addr/{ipv6}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ipv6"]

        self.b_key = "ipv6-addr"
        self.a10_url="/axapi/v3/network/lldp/management-address/ipv6-addr/{ipv6}"
        self.DeviceProxy = ""
        self.interface_ipv6 = {}
        self.ipv6 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class MemberList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param status: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param passive: {"type": "number", "format": "number"}
    :param connect_success: {"type": "number", "format": "number"}
    :param member_name: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param address: {"type": "string", "format": "ipv4-address"}
    :param sync_sequence_number: {"type": "number", "format": "number"}
    :param connect_fail: {"type": "number", "format": "number"}
    :param priority: {"type": "number", "format": "number"}
    :param group_name: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param open_out: {"type": "number", "format": "number"}
    :param learn: {"type": "number", "format": "number"}
    :param is_master: {"type": "number", "format": "number"}
    :param open_success: {"type": "number", "format": "number"}
    :param open_in: {"type": "number", "format": "number"}
    :param sys_id: {"type": "number", "format": "number"}
    :param update_in: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "member-list"
        self.DeviceProxy = ""
        self.status = ""
        self.passive = ""
        self.connect_success = ""
        self.member_name = ""
        self.address = ""
        self.sync_sequence_number = ""
        self.connect_fail = ""
        self.priority = ""
        self.group_name = ""
        self.open_out = ""
        self.learn = ""
        self.is_master = ""
        self.open_success = ""
        self.open_in = ""
        self.sys_id = ""
        self.update_in = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param member_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"status": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "passive": {"type": "number", "format": "number"}, "connect-success": {"type": "number", "format": "number"}, "member-name": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "address": {"type": "string", "format": "ipv4-address"}, "sync-sequence-number": {"type": "number", "format": "number"}, "connect-fail": {"type": "number", "format": "number"}, "priority": {"type": "number", "format": "number"}, "group-name": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "open-out": {"type": "number", "format": "number"}, "learn": {"type": "number", "format": "number"}, "is_master": {"type": "number", "format": "number"}, "open-success": {"type": "number", "format": "number"}, "open-in": {"type": "number", "format": "number"}, "optional": true, "sys-id": {"type": "number", "format": "number"}, "update-in": {"type": "number", "format": "number"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.member_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class GroupInfo(A10BaseClass):
    
    """Class Description::
    Operational Status for the object group-info.

    Class group-info supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/group-info/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "group-info"
        self.a10_url="/axapi/v3/gslb/group-info/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param bad_header_query: {"description": "Number of queries with incorrect header", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param total_response: {"description": "Total number of DNS replies sent to clients", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param bad_service_response: {"description": "Number of replies with unknown service", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param bad_service_query: {"description": "Number of queries with unknown service", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param bad_format_query: {"description": "Number of queries with incorrect format", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param bad_packet_query: {"description": "Number of queries with incorrect data length", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param total_query: {"description": "Total number of DNS queries received", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param no_answer: {"description": "Number of replies with unknown server IP", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param bad_class_query: {"description": "Number of queries with incorrect class", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param bad_type_query: {"description": "Number of queries with incorrect type", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param bad_packet_response: {"description": "Number of replies with incorrect data length", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param bad_class_response: {"description": "Number of replies with incorrect class", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param bad_format_response: {"description": "Number of replies with incorrect format", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param bad_type_response: {"description": "Number of replies with incorrect type", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param bad_header_response: {"description": "Number of replies with incorrect header", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.bad_header_query = ""
        self.total_response = ""
        self.bad_service_response = ""
        self.bad_service_query = ""
        self.bad_format_query = ""
        self.bad_packet_query = ""
        self.total_query = ""
        self.no_answer = ""
        self.bad_class_query = ""
        self.bad_type_query = ""
        self.bad_packet_response = ""
        self.bad_class_response = ""
        self.bad_format_response = ""
        self.bad_type_response = ""
        self.bad_header_response = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Dns(A10BaseClass):
    
    """Class Description::
    Statistics for the object dns.

    Class dns supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/dns/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "dns"
        self.a10_url="/axapi/v3/gslb/dns/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Saml(A10BaseClass):
    
    """Class Description::
    Configure SAML related settings.

    Class saml supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param service_provider_list: {"minItems": 1, "items": {"type": "service-provider"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"name": {"description": "Specify SAML authentication service provider name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "certificate": {"description": "SAML service provider certificate file", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "require-assertion-signed": {"type": "object", "properties": {"require-assertion-signed-enable": {"default": 0, "type": "number", "description": "Enable required signing of SAML assertion", "format": "flag"}}}, "single-logout-service": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "SLO-binding": {"enum": ["post", "redirect", "soap"], "type": "string", "description": "'post': POST binding of single logout service; 'redirect': Redirect binding of single logout service; 'soap': SOAP binding of single logout service; ", "format": "enum"}, "SLO-location": {"minLength": 1, "maxLength": 63, "type": "string", "description": "The location of name-id management service. (ex. /SAML/POST)", "format": "string-rlx"}}}]}, "service-url": {"description": "SAML service provider service URL (ex. https://www.a10networks.com/saml.sso)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "entity-id": {"description": "SAML service provider entity ID", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "assertion-consuming-service": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "assertion-index": {"description": "The index of assertion consuming service", "minimum": 0, "type": "number", "maximum": 5, "format": "number"}, "assertion-binding": {"enum": ["artifact", "paos", "post"], "type": "string", "description": "'artifact': Artifact binding of assertion consuming service; 'paos': PAOS binding of assertion consuming service; 'post': POST binding of assertion consuming service; ", "format": "enum"}, "assertion-location": {"minLength": 1, "maxLength": 63, "type": "string", "description": "The location of assertion consuming service endpoint. (ex. /SAML/POST)", "format": "string-rlx"}}}]}, "saml-request-signed": {"type": "object", "properties": {"saml-request-signed-disable": {"default": 0, "type": "number", "description": "Disable signing signature for SAML (Authn/Artifact Resolve) requests", "format": "flag"}}}, "soap-tls-certificate-validate": {"type": "object", "properties": {"soap-tls-certificate-validate-disable": {"default": 0, "type": "number", "description": "Disable verification for server certificate in TLS session when resolving artificate", "format": "flag"}}}, "artifact-resolution-service": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"artifact-location": {"minLength": 1, "maxLength": 63, "type": "string", "description": "The location of artifact resolution service. (ex. /SAML/POST)", "format": "string-rlx"}, "optional": true, "artifact-binding": {"enum": ["soap"], "type": "string", "description": "'soap': SOAP binding of artifact resolution service; ", "format": "enum"}, "artifact-index": {"description": "The index of artifact resolution service", "minimum": 0, "type": "number", "maximum": 5, "format": "number"}}}]}, "metadata-export-service": {"type": "object", "properties": {"md-export-location": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify the URI to export SP metadata (Export URI. Default is /A10SP_Metadata)", "format": "string-rlx"}, "sign-xml": {"default": 0, "type": "number", "description": "Sign exported SP metadata XML with SP's certificate", "format": "flag"}}}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/saml/service-provider/{name}"}
    :param identity_provider_list: {"minItems": 1, "items": {"type": "identity-provider"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"name": {"description": "SAML authentication identity provider name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "certificate": {"description": "SAML identity provider certificate file", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "metadata": {"description": "URL of SAML identity provider's metadata file", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/saml/identity-provider/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/saml`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "saml"
        self.a10_url="/axapi/v3/aam/authentication/saml"
        self.DeviceProxy = ""
        self.service_provider_list = []
        self.identity_provider_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param recv_client_command_RCPT: {"description": "Recv client RCPT", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param line_across_packet: {"description": "Line across packets", "format": "counter", "type": "number", "oid": "55", "optional": true, "size": "8"}
    :param forward_req_fail: {"description": "Forward request failure", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param server_select_fail: {"description": "Server selection failure", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param total_proxy: {"description": "Total proxy conns", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param recv_server_unknow_reply_code: {"description": "Recv server unknown-code", "format": "counter", "type": "number", "oid": "34", "optional": true, "size": "8"}
    :param too_many_headers: {"description": "Too many headers", "format": "counter", "type": "number", "oid": "53", "optional": true, "size": "8"}
    :param recv_client_command_QUIT: {"description": "Recv client QUIT", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "8"}
    :param recv_client_command_NOOP: {"description": "Recv client NOOP", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "8"}
    :param new_server_conn: {"description": "Server connection made", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param req_retran: {"description": "Request retransmit", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param recv_client_command_MAIL: {"description": "Recv client MAIL", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param client_domain_switch_ok: {"description": "Client domain sw (succ)", "format": "counter", "type": "number", "oid": "48", "optional": true, "size": "8"}
    :param recv_client_command_VRFY: {"description": "Recv client VRFY", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param server_prem_close: {"description": "Server premature close", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param Aflex_lb_reselect_ok: {"description": "aFleX lb reselect (succ)", "format": "counter", "type": "number", "oid": "65", "optional": true, "size": "8"}
    :param parse_resonse_line_fail: {"description": "Parse response line fail", "format": "counter", "type": "number", "oid": "63", "optional": true, "size": "8"}
    :param line_table_extend_fail: {"description": "Table extend fail", "format": "counter", "type": "number", "oid": "59", "optional": true, "size": "8"}
    :param send_client_close_connection: {"description": "Sent client close-conn", "format": "counter", "type": "number", "oid": "37", "optional": true, "size": "8"}
    :param forward_req_data_fail: {"description": "Forward REQ data failure", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param recv_client_command_RSET: {"description": "Recv client RSET", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param no_proxy: {"description": "No proxy error", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param client_reset: {"description": "Client reset", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param recv_client_command_DATA: {"description": "Recv client DATA", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param recv_client_command_HELP: {"description": "Recv client HELP", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "8"}
    :param send_client_start_TLS_first: {"description": "Sent client STARTTLS-1st", "format": "counter", "type": "number", "oid": "39", "optional": true, "size": "8"}
    :param recv_client_command_HELO: {"description": "Recv client HELO", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param recv_client_command_STARTTLS: {"description": "Recv client STARTTLS", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "8"}
    :param recv_client_command_others: {"description": "Recv client other cmds", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "8"}
    :param recv_client_command_EXPN: {"description": "Recv client EXPN", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param LB_switch: {"description": "LB switching", "format": "counter", "type": "number", "oid": "49", "optional": true, "size": "8"}
    :param no_tuple: {"description": "No tuple error", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param L4_switch: {"description": "L4 switching", "format": "counter", "type": "number", "oid": "44", "optional": true, "size": "8"}
    :param send_client_no_command: {"description": "Sent client no-such-cmd", "format": "counter", "type": "number", "oid": "41", "optional": true, "size": "8"}
    :param Aflex_switch_ok: {"description": "aFleX switching (succ)", "format": "counter", "type": "number", "oid": "46", "optional": true, "size": "8"}
    :param request_success: {"description": "SMTP requests (success)", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param tcp_out_reset: {"description": "TCP out reset", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param line_table_extend: {"description": "Table extend", "format": "counter", "type": "number", "oid": "58", "optional": true, "size": "8"}
    :param send_server_cmd_reset: {"description": "Sent server RSET", "format": "counter", "type": "number", "oid": "42", "optional": true, "size": "8"}
    :param line_extend_fail: {"description": "Line extend fail", "format": "counter", "type": "number", "oid": "57", "optional": true, "size": "8"}
    :param server_reselect: {"description": "Server reselection", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param Aflex_lb_reselect: {"description": "aFleX lb reselect", "format": "counter", "type": "number", "oid": "64", "optional": true, "size": "8"}
    :param curr_proxy: {"description": "Current proxy conns", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param send_client_service_ready: {"description": "Sent client serv-rdy", "format": "counter", "type": "number", "oid": "35", "optional": true, "size": "8"}
    :param send_client_go_ahead: {"description": "Sent client go-ahead", "format": "counter", "type": "number", "oid": "38", "optional": true, "size": "8"}
    :param req_ofo: {"description": "Request pkt out-of-order", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param client_domain_switch: {"description": "Client domain switching", "format": "counter", "type": "number", "oid": "47", "optional": true, "size": "8"}
    :param server_reset: {"description": "Server reset", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param snat_fail: {"description": "Source NAT failure", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param send_client_TLS_not_available: {"description": "Sent client TLS-not-aval", "format": "counter", "type": "number", "oid": "40", "optional": true, "size": "8"}
    :param parse_request_line_fail: {"description": "Parse request line fail", "format": "counter", "type": "number", "oid": "60", "optional": true, "size": "8"}
    :param remove_resonse_line_fail: {"description": "Del response line fail", "format": "counter", "type": "number", "oid": "62", "optional": true, "size": "8"}
    :param send_client_service_not_ready: {"description": "Sent client serv-not-rdy", "format": "counter", "type": "number", "oid": "36", "optional": true, "size": "8"}
    :param get_all_headers_fail: {"description": "Get all headers fail", "format": "counter", "type": "number", "oid": "52", "optional": true, "size": "8"}
    :param parse_req_fail: {"description": "Parse request failure", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param LB_switch_ok: {"description": "LB switching (succ)", "format": "counter", "type": "number", "oid": "50", "optional": true, "size": "8"}
    :param Aflex_switch: {"description": "aFleX switching", "format": "counter", "type": "number", "oid": "45", "optional": true, "size": "8"}
    :param line_too_long: {"description": "Line too long", "format": "counter", "type": "number", "oid": "54", "optional": true, "size": "8"}
    :param insert_resonse_line_fail: {"description": "Ins response line fail", "format": "counter", "type": "number", "oid": "61", "optional": true, "size": "8"}
    :param request: {"description": "SMTP requests", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param line_extend: {"description": "Line extend", "format": "counter", "type": "number", "oid": "56", "optional": true, "size": "8"}
    :param read_request_line_fail: {"description": "Read request line fail", "format": "counter", "type": "number", "oid": "51", "optional": true, "size": "8"}
    :param recv_client_command_EHLO: {"description": "Recv client EHLO", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param recv_server_service_not_ready: {"description": "Recv server serv-not-rdy", "format": "counter", "type": "number", "oid": "33", "optional": true, "size": "8"}
    :param TLS_established: {"description": "SSL session established", "format": "counter", "type": "number", "oid": "43", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.recv_client_command_RCPT = ""
        self.line_across_packet = ""
        self.forward_req_fail = ""
        self.server_select_fail = ""
        self.total_proxy = ""
        self.recv_server_unknow_reply_code = ""
        self.too_many_headers = ""
        self.recv_client_command_QUIT = ""
        self.recv_client_command_NOOP = ""
        self.new_server_conn = ""
        self.req_retran = ""
        self.recv_client_command_MAIL = ""
        self.client_domain_switch_ok = ""
        self.recv_client_command_VRFY = ""
        self.server_prem_close = ""
        self.Aflex_lb_reselect_ok = ""
        self.parse_resonse_line_fail = ""
        self.line_table_extend_fail = ""
        self.send_client_close_connection = ""
        self.forward_req_data_fail = ""
        self.recv_client_command_RSET = ""
        self.no_proxy = ""
        self.client_reset = ""
        self.recv_client_command_DATA = ""
        self.recv_client_command_HELP = ""
        self.send_client_start_TLS_first = ""
        self.recv_client_command_HELO = ""
        self.recv_client_command_STARTTLS = ""
        self.recv_client_command_others = ""
        self.recv_client_command_EXPN = ""
        self.LB_switch = ""
        self.no_tuple = ""
        self.L4_switch = ""
        self.send_client_no_command = ""
        self.Aflex_switch_ok = ""
        self.request_success = ""
        self.tcp_out_reset = ""
        self.line_table_extend = ""
        self.send_server_cmd_reset = ""
        self.line_extend_fail = ""
        self.server_reselect = ""
        self.Aflex_lb_reselect = ""
        self.curr_proxy = ""
        self.send_client_service_ready = ""
        self.send_client_go_ahead = ""
        self.req_ofo = ""
        self.client_domain_switch = ""
        self.server_reset = ""
        self.snat_fail = ""
        self.send_client_TLS_not_available = ""
        self.parse_request_line_fail = ""
        self.remove_resonse_line_fail = ""
        self.send_client_service_not_ready = ""
        self.get_all_headers_fail = ""
        self.parse_req_fail = ""
        self.LB_switch_ok = ""
        self.Aflex_switch = ""
        self.line_too_long = ""
        self.insert_resonse_line_fail = ""
        self.request = ""
        self.line_extend = ""
        self.read_request_line_fail = ""
        self.recv_client_command_EHLO = ""
        self.recv_server_service_not_ready = ""
        self.TLS_established = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Smtp(A10BaseClass):
    
    """Class Description::
    Statistics for the object smtp.

    Class smtp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/smtp/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "smtp"
        self.a10_url="/axapi/v3/slb/smtp/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class NoForwardMatch(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param send_icmpv6: {"default": 0, "type": "number", "description": "Send ICMPv6 Type 1 Code 5", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "no-forward-match"
        self.DeviceProxy = ""
        self.send_icmpv6 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NoReverseMatch(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param send_icmp: {"default": 0, "type": "number", "description": "Send ICMP Type 3 Code 1", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "no-reverse-match"
        self.DeviceProxy = ""
        self.send_icmp = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Global(A10BaseClass):
    
    """Class Description::
    Configure LW-4over6 parameters.

    Class global supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param nat_prefix_list: {"description": "Configure LW-4over6 NAT Prefix List (LW-4over6 NAT Prefix Class-list)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param hairpinning: {"description": "'filter-all': Disable all Hairpinning; 'filter-none': Allow all Hairpinning (default); 'filter-self-ip': Block Hairpinning to same IP; 'filter-self-ip-port': Block hairpinning to same IP and Port combination; ", "format": "enum", "default": "filter-none", "type": "string", "enum": ["filter-all", "filter-none", "filter-self-ip", "filter-self-ip-port"], "optional": true}
    :param icmp_inbound: {"description": "'drop': Drop Inbound ICMP packets; 'handle': Handle Inbound ICMP packets(default); ", "format": "enum", "default": "handle", "type": "string", "enum": ["drop", "handle"], "optional": true}
    :param use_binding_table: {"description": "Bind LW-4over6 binding table for use (LW-4over6 Binding Table Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param tunnel_endpoint_address: {"optional": true, "type": "string", "description": "Configure LW-4over6 IPIP Tunnel Endpoint Address (LW-4over6 Tunnel Endpoint Address)", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lw-4o6/global`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "global"
        self.a10_url="/axapi/v3/cgnv6/lw-4o6/global"
        self.DeviceProxy = ""
        self.no_forward_match = {}
        self.nat_prefix_list = ""
        self.hairpinning = ""
        self.icmp_inbound = ""
        self.use_binding_table = ""
        self.no_reverse_match = {}
        self.tunnel_endpoint_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Traps(A10BaseClass):
    
    """Class Description::
    Disable l3v partition SNMP traps.

    Class traps supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param gslb: {"default": 0, "optional": true, "type": "number", "description": "Disable all gslb traps on this partition", "format": "flag"}
    :param all: {"default": 0, "optional": true, "type": "number", "description": "Disable all traps on this partition", "format": "flag"}
    :param slb_change: {"default": 0, "optional": true, "type": "number", "description": "Disable all slb-change traps on this partition", "format": "flag"}
    :param snmp: {"default": 0, "optional": true, "type": "number", "description": "Disable all snmp traps on this partition", "format": "flag"}
    :param slb: {"default": 0, "optional": true, "type": "number", "description": "Disable all slb traps on this partition", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/disable/traps`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "traps"
        self.a10_url="/axapi/v3/snmp-server/disable/traps"
        self.DeviceProxy = ""
        self.gslb = ""
        self.A10WW_all = ""
        self.slb_change = ""
        self.snmp = ""
        self.slb = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param total_fwd_bytes: {"description": "Forward bytes", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param total_conn: {"description": "Total connections", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param total_fwd_packets: {"description": "Forward packets", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param curr_pconn: {"description": "Persistent connections", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param curr_conn: {"description": "Current connections", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param total_rev_packets: {"description": "Reverse packets", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param total_rev_bytes: {"description": "Reverse bytes", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.total_fwd_bytes = ""
        self.total_conn = ""
        self.total_fwd_packets = ""
        self.curr_pconn = ""
        self.curr_conn = ""
        self.total_rev_packets = ""
        self.total_rev_bytes = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Passthrough(A10BaseClass):
    
    """Class Description::
    Statistics for the object passthrough.

    Class passthrough supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/passthrough/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "passthrough"
        self.a10_url="/axapi/v3/slb/passthrough/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class UsableNatPorts(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param usable_start_port: {"description": "Start Port of Usable NAT Ports", "minimum": 1024, "type": "number", "maximum": 65535, "format": "number"}
    :param usable_end_port: {"description": "End Port of Usable NAT Ports", "minimum": 1024, "type": "number", "maximum": 65535, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "usable-nat-ports"
        self.DeviceProxy = ""
        self.usable_start_port = ""
        self.usable_end_port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Offset(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param numeric_offset: {"description": "Configure a numeric offset to the first NAT IP address", "format": "number", "default": 0, "maximum": 1024000, "minimum": 0, "not": "random", "type": "number"}
    :param random: {"default": 0, "not": "numeric-offset", "type": "number", "description": "Randomly choose the first NAT IP address", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "offset"
        self.DeviceProxy = ""
        self.numeric_offset = ""
        self.random = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6Address(A10BaseClass):
    
    """Class Description::
    Configure Fixed NAT.

    Class ipv6address supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ports_per_user: {"description": "Configure Ports per Inside User (ports-per-user)", "format": "number", "type": "number", "maximum": 64512, "minimum": 1, "optional": true}
    :param vrid: {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}
    :param inside_netmask: {"description": "Inside User IPv6 Netmask", "format": "number", "type": "number", "maximum": 128, "minimum": 64, "optional": false}
    :param nat_end_address: {"optional": true, "type": "string", "description": "IPv6 End NAT Address", "format": "ipv4-address"}
    :param partition: {"description": "Inside User Partition (Partition Name)", "partition-visibility": "shared", "minLength": 1, "format": "string", "optional": false, "maxLength": 63, "type": "string"}
    :param nat_netmask: {"optional": true, "type": "string", "description": "NAT Addresses IP Netmask", "format": "ipv4-netmask-brief"}
    :param session_quota: {"description": "Configure per user quota on sessions", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}
    :param method: {"description": "'use-all-nat-ips': Use all the NAT IP addresses configured; 'use-least-nat-ips': Use the least number of NAT IP addresses required (default); ", "format": "enum", "default": "use-least-nat-ips", "type": "string", "enum": ["use-all-nat-ips", "use-least-nat-ips"], "optional": true}
    :param inside_start_address: {"optional": false, "type": "string", "description": "IPv6 Inside User Start Address", "format": "ipv6-address"}
    :param nat_start_address: {"optional": true, "type": "string", "description": "Start NAT Address", "format": "ipv4-address"}
    :param nat_ip_list: {"description": "Name of IP List used to specify NAT addresses", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param respond_to_user_mac: {"default": 0, "optional": true, "type": "number", "description": "Use the user's source MAC for the next hop rather than the routing table (Default: off)", "format": "flag"}
    :param inside_end_address: {"optional": false, "type": "string", "description": "IPv6 Inside User End Address", "format": "ipv6-address"}
    :param dest_rule_list: {"description": "Bind destination based Rule-List (Fixed NAT Rule-List Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param dynamic_pool_size: {"description": "Configure size of Dynamic pool (Default: 0)", "format": "number", "default": 0, "optional": true, "maximum": 64511, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/fixed-nat/inside/ipv6address/{inside_start_address}+{inside_end_address}+{inside_netmask}+{partition}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "inside_start_address","inside_end_address","inside_netmask","partition"]

        self.b_key = "ipv6address"
        self.a10_url="/axapi/v3/cgnv6/fixed-nat/inside/ipv6address/{inside_start_address}+{inside_end_address}+{inside_netmask}+{partition}"
        self.DeviceProxy = ""
        self.ports_per_user = ""
        self.vrid = ""
        self.inside_netmask = ""
        self.nat_end_address = ""
        self.usable_nat_ports = {}
        self.partition = ""
        self.nat_netmask = ""
        self.session_quota = ""
        self.method = ""
        self.inside_start_address = ""
        self.nat_start_address = ""
        self.nat_ip_list = ""
        self.offset = {}
        self.respond_to_user_mac = ""
        self.inside_end_address = ""
        self.dest_rule_list = ""
        self.dynamic_pool_size = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Prefix(A10BaseClass):
    
    """Class Description::
    Configure NAT64 Prefix.

    Class prefix supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param vrid: {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}
    :param prefix_val: {"optional": false, "type": "string", "description": "NAT64 Prefix", "format": "ipv6-address-plen"}
    :param class_list: {"description": "Class-list to match for NAT64", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/nat64/prefix/{prefix_val}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "prefix_val"]

        self.b_key = "prefix"
        self.a10_url="/axapi/v3/cgnv6/nat64/prefix/{prefix_val}"
        self.DeviceProxy = ""
        self.vrid = ""
        self.prefix_val = ""
        self.class_list = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


